==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ManagedIdentityPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs.builder
import com.pulumi.azurenative.appplatform.kotlin.enums.ManagedIdentityType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Managed identity properties retrieved from ARM request headers.
 * @property principalId Principal Id of system-assigned managed identity.
 * @property tenantId Tenant Id of system-assigned managed identity.
 * @property type Type of the managed identity
 * @property userAssignedIdentities Properties of user-assigned managed identities
 */
public data class ManagedIdentityPropertiesArgs(
    public val principalId: Output<String>? = null,
    public val tenantId: Output<String>? = null,
    public val type: Output<Either<String, ManagedIdentityType>>? = null,
    public val userAssignedIdentities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs.builder()
            .principalId(principalId?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .userAssignedIdentities(
                userAssignedIdentities?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedIdentityPropertiesArgs].
 */
@PulumiTagMarker
public class ManagedIdentityPropertiesArgsBuilder internal constructor() {
    private var principalId: Output<String>? = null

    private var tenantId: Output<String>? = null

    private var type: Output<Either<String, ManagedIdentityType>>? = null

    private var userAssignedIdentities: Output<List<String>>? = null

    /**
     * @param value Principal Id of system-assigned managed identity.
     */
    @JvmName("anjnrnqfdtbaptst")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value Tenant Id of system-assigned managed identity.
     */
    @JvmName("gwfslsveahsywior")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("erobiusehlduxdlj")
    public suspend fun type(`value`: Output<Either<String, ManagedIdentityType>>) {
        this.type = value
    }

    /**
     * @param value Properties of user-assigned managed identities
     */
    @JvmName("jjictgodcpqbhjqd")
    public suspend fun userAssignedIdentities(`value`: Output<List<String>>) {
        this.userAssignedIdentities = value
    }

    @JvmName("jwiyabjcovwshemr")
    public suspend fun userAssignedIdentities(vararg values: Output<String>) {
        this.userAssignedIdentities = Output.all(values.asList())
    }

    /**
     * @param values Properties of user-assigned managed identities
     */
    @JvmName("vhueeayuibguljhu")
    public suspend fun userAssignedIdentities(values: List<Output<String>>) {
        this.userAssignedIdentities = Output.all(values)
    }

    /**
     * @param value Principal Id of system-assigned managed identity.
     */
    @JvmName("rkauyeymorcnprix")
    public suspend fun principalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value Tenant Id of system-assigned managed identity.
     */
    @JvmName("nqwxcvxytbjoroip")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("gxoeddwlmrnrmtap")
    public suspend fun type(`value`: Either<String, ManagedIdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("aqdnrcltlstmrlis")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("omxpcurvkbvfvykj")
    public fun type(`value`: ManagedIdentityType) {
        val toBeMapped = Either.ofRight<String, ManagedIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Properties of user-assigned managed identities
     */
    @JvmName("ifpikleptupitcvr")
    public suspend fun userAssignedIdentities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    /**
     * @param values Properties of user-assigned managed identities
     */
    @JvmName("hnoetikaaqehbjxx")
    public suspend fun userAssignedIdentities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    internal fun build(): ManagedIdentityPropertiesArgs = ManagedIdentityPropertiesArgs(
        principalId = principalId,
        tenantId = tenantId,
        type = type,
        userAssignedIdentities = userAssignedIdentities,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ManagedIdentityPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs.builder
import com.pulumi.azurenative.appplatform.kotlin.enums.ManagedIdentityType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Managed identity properties retrieved from ARM request headers.
 * @property principalId Principal Id of system-assigned managed identity.
 * @property tenantId Tenant Id of system-assigned managed identity.
 * @property type Type of the managed identity
 * @property userAssignedIdentities Properties of user-assigned managed identities
 */
public data class ManagedIdentityPropertiesArgs(
    public val principalId: Output<String>? = null,
    public val tenantId: Output<String>? = null,
    public val type: Output<Either<String, ManagedIdentityType>>? = null,
    public val userAssignedIdentities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.ManagedIdentityPropertiesArgs.builder()
            .principalId(principalId?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .userAssignedIdentities(
                userAssignedIdentities?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedIdentityPropertiesArgs].
 */
@PulumiTagMarker
public class ManagedIdentityPropertiesArgsBuilder internal constructor() {
    private var principalId: Output<String>? = null

    private var tenantId: Output<String>? = null

    private var type: Output<Either<String, ManagedIdentityType>>? = null

    private var userAssignedIdentities: Output<List<String>>? = null

    /**
     * @param value Principal Id of system-assigned managed identity.
     */
    @JvmName("qxfusatvioyldlnj")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value Tenant Id of system-assigned managed identity.
     */
    @JvmName("emcqarsgclspytio")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("ngubokxuancpxexy")
    public suspend fun type(`value`: Output<Either<String, ManagedIdentityType>>) {
        this.type = value
    }

    /**
     * @param value Properties of user-assigned managed identities
     */
    @JvmName("qxumuuwqcawjcqhv")
    public suspend fun userAssignedIdentities(`value`: Output<List<String>>) {
        this.userAssignedIdentities = value
    }

    @JvmName("osqlrnofsgeokldd")
    public suspend fun userAssignedIdentities(vararg values: Output<String>) {
        this.userAssignedIdentities = Output.all(values.asList())
    }

    /**
     * @param values Properties of user-assigned managed identities
     */
    @JvmName("yqixefqmgcskjnet")
    public suspend fun userAssignedIdentities(values: List<Output<String>>) {
        this.userAssignedIdentities = Output.all(values)
    }

    /**
     * @param value Principal Id of system-assigned managed identity.
     */
    @JvmName("vfnibcbfhfhsxogy")
    public suspend fun principalId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value Tenant Id of system-assigned managed identity.
     */
    @JvmName("ywucnqdsvhvtcyec")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("vgbflaunjnadrlyc")
    public suspend fun type(`value`: Either<String, ManagedIdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("pejlqieilpuefrpa")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of the managed identity
     */
    @JvmName("rvloobwvlkbqudue")
    public fun type(`value`: ManagedIdentityType) {
        val toBeMapped = Either.ofRight<String, ManagedIdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Properties of user-assigned managed identities
     */
    @JvmName("ujikdvippgdkajwx")
    public suspend fun userAssignedIdentities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    /**
     * @param values Properties of user-assigned managed identities
     */
    @JvmName("hhttkojnkjbrxfhc")
    public suspend fun userAssignedIdentities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userAssignedIdentities = mapped
    }

    internal fun build(): ManagedIdentityPropertiesArgs = ManagedIdentityPropertiesArgs(
        principalId = principalId,
        tenantId = tenantId,
        type = type,
        userAssignedIdentities = userAssignedIdentities,
    )
}
